--[[

SurfaceControl, controls what SurfaceLib returns from the Fetch method.
Copyright (C) 2007 rabbit.magtheridon@gmail.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

]]

local surface = AceLibrary("Surface-1.0")

SurfaceControl = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceDB-2.0", "AceConsole-2.0")

SurfaceControl:RegisterDB("SurfaceControlDB")
SurfaceControl:RegisterDefaults("profile", {
	texture = nil,
})

SurfaceControl:RegisterChatCommand({ "/surfacecontrol" }, {
	type = "text",
	name = "Texture",
	desc = "Set the override texture for SurfaceLib.",
	usage = "<texture>",
	get = function() return SurfaceControl.db.profile.texture end,
	set = function(v)
		SurfaceControl.db.profile.texture = v
		SurfaceControl:SetGlobal()
	end,
	validate = surface:List(),
}, "SURFACECONTROL")

local orig = nil
local oldRevision = nil

function SurfaceControl:OnEnable()
	self:RegisterEvent("AceEvent_FullyInitialized")
	self:RegisterEvent("AceLibrary_Register")

	if AceLibrary("AceEvent-2.0"):IsFullyInitialized() then
		self:AceEvent_FullyInitialized()
	end
end

function SurfaceControl:AceEvent_FullyInitialized()
	self:SetGlobal()
end

function SurfaceControl:AceLibrary_Register(major, instance)
	if major == "Surface-1.0" and SurfaceControl.db.profile.texture then
		self:SetGlobal(instance)
	end
end

function SurfaceControl:SetGlobal(instance)
	local texture = SurfaceControl.db.profile.texture

	if not instance then instance = surface end

	if type(instance.SetGlobal) ~= "function" or type(instance.IsValid) ~= "function" then return end
	if type(texture) ~= "string" or not instance:IsValid(texture) then return end

	instance:SetGlobal(texture)

	self:UpdateAddons()
end

function SurfaceControl:UpdateAddons()
	-- Any addons that need to be reset
	if type(aUF) == "table" and type(aUF.CallUnitMethods) == "function" then
		aUF:CallUnitMethods("BarTexture")
	end

	if type(CBRipoff) == "table" and type(CBRipoff.Layout) == "function" then
		CBRipoff:Layout("CastingBar")
		CBRipoff:Layout("BREATH", "MirrorBar")
		CBRipoff:Layout("EXHAUSTION", "MirrorBar")
		CBRipoff:Layout("FEIGNDEATH", "MirrorBar")
	end
end

